isPlaying property
bool
get
isPlaying
Returns true if an audio file is currently playing.
Implementation
static bool get isPlaying => _isPlaying;
Returns true if an audio file is currently playing.
static bool get isPlaying => _isPlaying;