isPaused property
bool
get
isPaused
Returns true if the active recording is currently paused.
Implementation
static bool get isPaused => _isPaused;
Returns true if the active recording is currently paused.
static bool get isPaused => _isPaused;