isRecording property
bool
get
isRecording
Returns true if the recorder is currently actively recording or paused.
Implementation
static bool get isRecording => _isRecording;
Returns true if the recorder is currently actively recording or paused.
static bool get isRecording => _isRecording;