pause static method
void
pause()
Pauses the current audio recording if one is active.
Implementation
static void pause() {
if (_isRecording && !_isPaused) {
_pauseNative();
_isPaused = true;
}
}
Pauses the current audio recording if one is active.
static void pause() {
if (_isRecording && !_isPaused) {
_pauseNative();
_isPaused = true;
}
}