AudioPlayer class
A utility class for playing audio files using native FFI calls.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
pause(
) → void - Pauses the currently playing audio.
-
play(
String filePath) → bool -
Starts or resumes playing an audio file from the given
filePath. Returns true if the playback started successfully. -
restart(
) → void - Restarts the currently loaded audio from the beginning.
-
resume(
) → void - Resumes the currently paused audio.
-
stop(
) → void - Stops the audio playback entirely.