AudioRecorder class
A utility class for recording audio using native FFI calls.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isPaused → bool
-
Returns true if the active recording is currently paused.
no setter
- isRecording → bool
-
Returns true if the recorder is currently actively recording or paused.
no setter
Static Methods
-
pause(
) → void - Pauses the current audio recording if one is active.
-
resume(
) → void - Resumes a paused audio recording.
-
start(
String filePath) → bool -
Starts recording audio to the specified
filePath. Returns true if the recording started successfully. -
stop(
) → void - Stops the current audio recording and finalizes the file.